@@ -7,7 +7,7 @@
 
   \author Satofumi KAMIMURA
 
-  $Id: gd_scan.c 1683 2010-02-10 10:28:05Z satofumi $
+  $Id: gd_scan.c 1939 2010-11-22 02:05:24Z satofumi $
 */
 
 #include "urg_ctrl.h"
@@ -34,6 +34,8 @@ int main(int argc, char *argv[])
 #else
   const char device[] = "/dev/ttyACM0"; /* For Linux */
 #endif
+  (void)argc;
+  (void)argv;
 
   int data_max;
   long *data;
@@ -44,6 +46,7 @@ int main(int argc, char *argv[])
 
   /* Connection */
   urg_t urg;
+  urg_initialize(&urg);
   ret = urg_connect(&urg, device, 115200);
   if (ret < 0) {
     urg_exit(&urg, "urg_connect()");
