@@ -1,6 +1,6 @@
 /*!
   \file
-  \brief シリアル送受信の補助
+  \brief VAM̕⏕
 
   \author Satofumi KAMIMURA
 
@@ -14,26 +14,26 @@
 #include <ctype.h>
 
 
-/* 改行かの判定 */
+/* s̔ */
 int serial_isLF(const char ch)
 {
   return ((ch == '\r') || (ch == '\n')) ? 1 : 0;
 }
 
 
-/* 受信データの読み飛ばし */
+/* Mf[^̓ǂݔ΂ */
 void serial_skip(serial_t *serial, int total_timeout, int each_timeout)
 {
   char recv_ch;
 
-  /* 書き戻した文字をクリア */
+  /* ߂NA */
   serial->last_ch_ = '\0';
 
   if (each_timeout <= 0) {
     each_timeout = total_timeout;
   }
 
-  // !!! total_timeout をこのループ条件に適用すべき
+  // !!! total_timeout ̃[vɓKpׂ
   while (1) {
     int n = serial_recv(serial, &recv_ch, 1, each_timeout);
     if (n <= 0) {
@@ -43,11 +43,11 @@ void serial_skip(serial_t *serial, int total_timeout, int each_timeout)
 }
 
 
-/* 改行までの読みだし */
+/* s܂ł̓ǂ݂ */
 int serial_getLine(serial_t *serial, char* data, int data_size_max,
                    int timeout)
 {
-  /* １文字ずつ読みだして評価する */
+  /* Pǂ݂ĕ] */
   int filled = 0;
   int is_timeout = 0;
 
