@@ -3,20 +3,21 @@
 
 /*!
   \file
-  \brief ロッククラス
+  \brief bNNX
 
   \author Satofumi KAMIMURA
 
-  $Id: Lock.h 783 2009-05-05 08:56:26Z satofumi $
+  $Id: Lock.h 1949 2011-05-06 07:18:01Z satofumi $
 */
 
 #include "ConditionVariable.h"
+#include <cstddef>
 
 
 namespace qrk
 {
   /*!
-    \brief ロッククラス
+    \brief bNNX
   */
   class Lock {
 
@@ -26,9 +27,9 @@ namespace qrk
     Lock(const Lock& rhs);
     Lock& operator = (const Lock& rhs);
 
-    // !!! ?
-    void* operator new (size_t);
-    void* operator new[] (size_t);
+    // !!!
+    //void* operator new (size_t);
+    //void* operator new[] (size_t);
 
     struct pImpl;
     const std::auto_ptr<pImpl> pimpl;
@@ -39,13 +40,19 @@ namespace qrk
 
 
     /*!
-      \brief ロック
+      \brief bN
     */
     void lock(void);
 
 
     /*!
-      \brief アンロック
+      \brief bN
+    */
+    bool tryLock(void);
+
+
+    /*!
+      \brief AbN
     */
     void unlock(void);
   };
