@@ -1,6 +1,6 @@
 /*!
   \file
-  \brief 待機関数
+  \brief ҋ@֐
 
   \author Satofumi KAMIMURA
 
@@ -31,10 +31,10 @@ void qrk::delay(int msec)
     system_delay(msec);
 
   } else {
-    // 再生時、シミュレーション時は、
-    // 唯一の StopWatch を用いた時間を返す関数として動作する
+    // ĐAV~[V́A
+    // B StopWatch pԂԂ֐Ƃē삷
     // !!!
-    // !!! 仮実装
+    // !!! 
     system_delay(msec);
   }
 }
